@@ -22,6 +22,9 @@
 #include "box_db.h" //For Box_DB::connect_to_server().
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_Connection::Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   Base_DB(),
@@ -44,7 +47,7 @@ sharedptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection
 {
   //std::cout << "debug: Dialog_Connection::connect_to_server_with_connection_settings()" << std::endl;
 
-  //TODO: Bakery::BusyCursor(*get_app_window());
+  //TODO: Bakery::BusyCursor busy_cursor(get_app_window());
 
   sharedptr<SharedConnection> result(0);
 
@@ -71,7 +74,7 @@ sharedptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection
 
     connection_pool->set_ready_to_connect(); //Box_DB::connect_to_server() will now attempt the connection-> Shared instances of m_Connection will also be usable.
 
-    result = Box_DB::connect_to_server();
+    result = Box_DB::connect_to_server(const_cast<Dialog_Connection*>(this));
 
     /*
     if(document)
@@ -93,7 +96,10 @@ void Dialog_Connection::load_from_document()
   if(document)
   {
     //Load server and user:
-    m_entry_host->set_text(document->get_connection_server());
+    Glib::ustring host = document->get_connection_server();
+    if(host.empty())
+      host = "localhost";
+    m_entry_host->set_text(host);
 
     Glib::ustring user = document->get_connection_user(); //TODO: Offer a drop-down list of users.
 
@@ -125,3 +131,4 @@ void Dialog_Connection::set_database_name(const Glib::ustring& name)
     m_label_database->set_text(name);
 }
 
+} //namespace Glom
