@@ -25,6 +25,9 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 
+namespace Glom
+{
+
 class Dialog_NewDatabase : public Gtk::Dialog
 {
 public:
@@ -44,5 +47,7 @@ protected:
   Gtk::Button* m_button_ok;
 };
 
+} //namespace Glom
+
 #endif //GLOM_DIALOG_NEWDATABASE_H
 
