@@ -25,8 +25,10 @@
 #include <libgnomecanvasmm.h>
 #include "relationshipscanvas_tablewidget.h"
 #include "../base_db.h"
-#include "../data_structure/tableinfo.h"
+#include <glom/libglom/data_structure/tableinfo.h>
 
+namespace Glom
+{
 
 class TableCanvasItem
   : public Gnome::Canvas::Group,
@@ -64,4 +66,6 @@ protected:
   sharedptr<const TableInfo> m_table_info;
 };
 
+} //namespace Glom
+
 #endif //GLOM_RELATIONSHIPS_OVERVIEW_TABLE_CANVASITEM_H
