@@ -25,6 +25,7 @@
 #include <glom/libglom/data_structure/glomconversions.h> //For util_build_sql
 #include <glom/libglom/utils.h>
 
+#include "glom/application.h"
 
 namespace Glom
 {
@@ -178,7 +179,7 @@ DbTreeModel::DbTreeModel(const Gtk::TreeModelColumnRecord& columns, const FoundS
 
   g_assert(m_columns_count == column_fields.size());
 
-  //refresh_from_database();
+  refresh_from_database(m_found_set);
 }
 
 DbTreeModel::~DbTreeModel()
@@ -194,6 +195,7 @@ Glib::RefPtr<DbTreeModel> DbTreeModel::create(const Gtk::TreeModelColumnRecord&
 
 bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 {
+  //std::cout << "DbTreeModel::refresh_from_database()" << std::endl;
   m_found_set = found_set;
 
   if(!m_get_records)
@@ -211,8 +213,20 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
   if(m_connection && !m_found_set.m_table_name.empty() && m_get_records)
   {
     const Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_sort_clause);
+    //std::cout << "  Debug: query_execute():  " << sql_query << std::endl;
 
-    //std::cout << "DbTreeModel: Executing SQL: " << sql_query << std::endl << std::endl;
+    const App_Glom* app = App_Glom::get_application();
+    if(app && app->get_show_sql_debug())
+    { 
+      try
+      {
+        std::cout << "Debug: query_execute():  " << sql_query << std::endl;
+      }
+      catch(const Glib::Exception& ex)
+      {
+        std::cout << "Debug: query string could not be converted to std::cout: " << ex.what() << std::endl;
+      }
+    }
     try
     {
       m_gda_datamodel = m_connection->get_gda_connection()->execute_single_command(sql_query);
@@ -227,6 +241,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_data_model_rows_count = 0;
       m_data_model_columns_count = m_columns_count;
 
+      std::cerr << "DbTreeModel::refresh_from_database(): error executing SQL: " << sql_query << std::endl;
       ConnectionPool::handle_error();
       return false; //No records were found.
     }
